@@ -1,6 +1,13 @@
-/*  gtktiemu - a TI89/92/92+ emulator
- *  (c) Copyright 2000, Romain Lievin and Thomas Corvazier
- *  (c) Copyright 2001, Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: m68k.h 1455 2005-05-31 18:38:03Z roms $ */
+
+/*  TiEmu - an TI emulator
+ *
+ *  Copyright (c) 2000-2001, Thomas Corvazier, Romain Lievin
+ *  Copyright (c) 2001-2003, Romain Lievin
+ *  Copyright (c) 2003, Julien Blache
+ *  Copyright (c) 2004, Romain Livin
+ *  Copyright (c) 2005, Romain Livin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,20 +21,19 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __TI68K_M68K__
 #define __TI68K_M68K__
 
-/* Functions */
+int hw_m68k_init(void);
+int hw_m68k_reset(void);
+int hw_m68k_exit(void);
 
-void hw_init_m68k(void);
-void hw_reset_m68k(void);
-void hw_exit_m68k(void);
-int  hw_run_m68k(int);
-
-/* Variables */
+int hw_m68k_run(int ninsts, unsigned int maxcycles);
+unsigned int hw_m68k_get_cycle_count(int);
 
+void hw_m68k_irq(int n);
 
 #endif
